@@ -1,6 +1,7 @@
-__version__ = "0.1.3"
+__version__ = "0.1.4"
 
 import logging
+from logging.handlers import RotatingFileHandler
 from logutils.consts import (
     lila,
     lime_green,
@@ -54,16 +55,16 @@ class CustomFormatter(logging.Formatter):
         return formatter.format(record)
 
 
-def get_logger(
-    name, level=logging.INFO, handler_type="stream", propagate=False, colored=True
-):
+def get_logger(name, level=logging.INFO, propagate=False, colored=True, filepath=None):
     logger = logging.getLogger(name)
     logger.setLevel(logging.DEBUG)
-    match handler_type:
-        case "stream":
-            handler = logging.StreamHandler()
-        case _:
-            raise Exception(f"Handler {handler_type} not supported")
+    if filepath is None:
+        handler = logging.StreamHandler()
+    else:
+        colored = False
+        handler = RotatingFileHandler(
+            filepath, maxBytes=(1 * 100 * 1024 * 1024), backupCount=10
+        )
     if level not in (
         logging.DEBUG,
         logging.INFO,
